@@ -41,13 +41,12 @@ else:
 # Let IPython decide about which debugger class to use
 # This is especially important for tools that fiddle with stdout
 debugger_cls = shell.debugger_cls
-def_colors = shell.colors
 
 def _init_pdb(context=3, commands=[]):
     try:
-        p = debugger_cls(def_colors, context=context)
+        p = debugger_cls(context=context)
     except TypeError:
-        p = debugger_cls(def_colors)
+        p = debugger_cls()
     p.rcLines.extend(commands)
     return p
 
@@ -135,12 +134,8 @@ def main():
         class Restart(Exception):
             pass
     
-    opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['--help', '--command='])
+    opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['help', 'command='])
 
-    if not args:
-        print(_usage)
-        sys.exit(2)
-    
     commands = []
     for opt, optarg in opts:
         if opt in ['-h', '--help']:
@@ -149,6 +144,10 @@ def main():
         elif opt in ['-c', '--command']:
             commands.append(optarg)
 
+    if not args:
+        print(_usage)
+        sys.exit(2)
+    
     mainpyfile = args[0]     # Get script filename
     if not os.path.exists(mainpyfile):
         print('Error:', mainpyfile, 'does not exist')
